@@ -14,9 +14,19 @@ C      DOUBLE PRECISION TIMEA,TIMEB,TIMTOT,A(50,50),EPS
       REAL S1
       INTEGER X(N),Q(N),S(N),UNSEL(N)
 
+C Helper variables for R-style output
+      CHARACTER(50) WRITESTRING
+      INTEGER DUMMY
+
+
       IF (IVERB == 1) THEN
-          PRINT *,'Anti-Robinson Seriation by branch-and-bound'
-          PRINT *,'based on bbwrcg.f by Brusco, and Stahl, S. (2005)'
+C          PRINT *,'Anti-Robinson Seriation by branch-and-bound'
+C          PRINT *,'based on bbwrcg.f by Brusco, and Stahl, S. (2005)'
+          CALL INTPR('Anti-Robinson seriation by branch-and-bound',
+     1 -1, DUMMY, 0)
+          CALL INTPR('based on bbwrcg.f by Brusco, and Stahl (2005)',
+     1 -1, DUMMY, 0)
+          CALL INTPR(' ', -1, DUMMY, 0)
       ENDIF
 
       OLDM=0
@@ -171,7 +181,9 @@ C
  3500 CONTINUE
 C      WRITE(2,3505) ZBEST
       IF (IVERB == 1) THEN
-          WRITE(*,3505) ZBEST
+C          WRITE(*,3505) ZBEST
+	  WRITE(WRITESTRING, 3505) ZBEST
+	  CALL INTPR(WRITESTRING, -1, DUMMY, 0)
       ENDIF
  3505 FORMAT(' HEURISTIC OBJ VALUE ',F20.4)
       Z = ZBEST-1
@@ -192,7 +204,9 @@ C
 C
       CHECKS=CHECKS+1
       IF (IVERB == 1 .AND. M .GT. OLDM) THEN
-          WRITE (*,6000) M+1, CHECKS
+C          WRITE (*,6000) M+1, CHECKS
+	  WRITE(WRITESTRING, 6000)  M+1, CHECKS
+	  CALL INTPR(WRITESTRING, -1, DUMMY, 0)
  6000 FORMAT('reached position ', I5, ' with ', I9, ' checks')
           OLDM=M
       ENDIF
@@ -218,7 +232,9 @@ C
         IF(ZBD.GT.Z) THEN
           Z=ZBD
           IF (IVERB == 1) THEN
-              WRITE(*,*) 'Eval =',z
+C              WRITE(*,*) 'Eval =',z
+              WRITE(WRITESTRING, *) 'Eval =',z
+	      CALL INTPR(WRITESTRING, -1, DUMMY, 0)
           ENDIF
           DO I = 1,N
             X(I)=Q(I)
@@ -368,7 +384,9 @@ C     1        F8.2)
 C 70   FORMAT(30I3)
 C
   9   IF (IVERB == 1) THEN
-          PRINT *, 'total number of checks: ', CHECKS
+C          PRINT *, 'total number of checks: ', CHECKS
+          WRITE(WRITESTRING, *)  'total number of checks: ', CHECKS
+          CALL INTPR(WRITESTRING, -1, DUMMY, 0)
       ENDIF
   
       RETURN
